pub struct BluetoothCamera { /* private fields */ }Implementations
Sourceimpl BluetoothCamera
impl BluetoothCamera
Sourcepub async fn new(name: &str) -> Result<BluetoothCamera, BluetoothCameraError>
pub async fn new(name: &str) -> Result<BluetoothCamera, BluetoothCameraError>
Takes the BLE name of the camera and returns a new BluetoothCamera instance
Arguments
name- &str representing the Bluetooth name of the camera such as “A:5CA7128B”
Sourcepub async fn connect(
&mut self,
timeout: Duration,
) -> Result<(), BluetoothCameraError>
pub async fn connect( &mut self, timeout: Duration, ) -> Result<(), BluetoothCameraError>
Tries to connect to the camera, waiting as long as supplied timeout specifies
Arguments
timeout- std::Duration of how long to wait before giving up
Sourcepub async fn disconnect(&mut self) -> Result<(), BluetoothCameraError>
pub async fn disconnect(&mut self) -> Result<(), BluetoothCameraError>
Disconnects from the camera
NOTE: THIS ACTUALLY DOESN’T WORK ON OSX BECAUSE THE UNDERLYING LIBRARY IS PEPEGA
pub async fn write( &mut self, destination: u8, operation: Operation, command: Command, ) -> Result<(), BluetoothCameraError>
Sourcepub async fn get(&self, cmd: Command) -> Command
pub async fn get(&self, cmd: Command) -> Command
Gives you the latest cached version of the supplied Command If no cached version is found, returns the empty property
Arguments
cmd- Command like this: Command::Metadata(Metadata::LensDistance(“”.to_string()))